@@ -12,7 +12,7 @@ from django.db import models as django_models
 from django.db.models.query_utils import DeferredAttribute
 
 from .utils import check_types, check_classes, get_ids_from_untyped_data
-from .cache import default_cache_func, django_sync_to_async_list, django_sync_to_async_get
+from .cache import Cache, django_sync_to_async_list, django_sync_to_async_get
 
 
 class RedisField:
@@ -176,7 +176,19 @@ class RedisForeignKey(RedisNumber):
             check_types(value, int)
             model_name = self.model.__name__
             instance_id = value
-            value = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')[instance_id]
+            instance_qs = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')
+            if instance_id in instance_qs.keys():
+                value = instance_qs[instance_id]
+            else:
+                instances_qs = redis_root.get_by_redis_model(self.model, id=instance_id)
+                if instances_qs:
+                    value = instances_qs[0]
+                else:
+                    instances_qs = redis_root.get_by_redis_model(self.model, django_id=instance_id)
+                    if instances_qs:
+                        value = instances_qs[0]
+                    else:
+                        value = {'id': value}
         else:
             value = None
         return value
@@ -676,7 +688,7 @@ class RedisRoot:
                   f'\n')
 
             redis_model = self.get_or_create_redis_model_from_django_model(django_model)
-            default_cache_func(
+            Cache(
                 self,
                 django_model,
                 cache_conf,
