@@ -42,7 +42,7 @@ class RedisQuerySet(django_models.query.QuerySet):
         return create_result
 
     def delete(self):
-        list_self = list(self.copy())
+        list_self = list(self).copy()
         concrete_model = self.model._meta.concrete_model
         delete_result = super().delete()
         redis_root = get_redis_root()
